<?php
/**
 * phpaga
 *
 * billing plugin
 *
 * This plugin contains the necessary routines to calculate a bill for:
 *
 * BE VAT
 *
 * @author Tim Esselens <tim.esselens@gmail.com>
 * @version $Id$
 *
 * Copyright (c) 2008, Tim Esselens
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Calculates the amount to be paid based on a startsum according to the
 * specified rules. Returns also an array containing all the documented
 * steps for this kind of billing method.
 *
 * @param real   $startsum  Start amount as base of calculation
 * @param int    $curr_id   Currency-ID
 * @param real   $endsum    The calculated amount to be paid
 * @param array  $details   Billing details
 *
 * @return void
 *
 * @author Tim Esselens <tim.esselens@gmail.com>
 */

function phpaga_bill_calculate ($startsum, $curr_id = "",
				&$endsum, &$details, $expensesum = 0, $paymentsum=0, $feesum=0)
{
    $details = new phpaga_bill_details ($curr_id);
    $endsum = 0;

    $inps = 0;
    $imponibile = 0;
    $iva = 0;
    $irpef = 0;

    /* 21% VAT */
    $inps = $startsum * 0.21;

    /* end sum */
    $preendsum = $startsum + $inps;
    $endsum = $preendsum + $expensesum;

    $details->add_detail ("Totaal excl. BTW", $startsum);
    $details->add_detail ("BTW 21%", $inps);
    $details->add_separator ();

    if (is_numeric($expensesum) && ($expensesum > 0)) {
        $details->add_detail(_("Subtotal"), $preendsum);
        $details->add_detail(_("+ Reimbursable expenses"), $expensesum);
        $details->add_separator ();
    }

    /* Add Latefees to bill details */
    if (is_numeric($feesum) && ($feesum > 0)) {
        $details->add_fee_detail(_("+ Late Fees"), $feesum);
    }

    /* Add Payments to bill details */
    if (is_numeric($paymentsum) && ($paymentsum > 0)) {
        $details->add_payment_detail(_("- Payments"), $paymentsum);
        $details->add_separator ();
    } else {
        $details->add_separator ();
    }


    $details->add_detail ("Totaal incl. BTW", $endsum-$paymentsum+$feesum);
}

?>
